@@ -13,11 +13,11 @@
 #' as lossless as possible. Some exceptions to this are if date/time columns are
 #' not in UTC (in which case they will be converted to UTC before writing), and
 #' if table names have characters that are not filesystem safe (allowed
-#' characters are [A-Za-z0-9_.-] and others will be stripped).
+#' characters are `[A-Za-z0-9_.-]` and others will be stripped).
 #' 
 #' @param md A mudata object
 #' @param filename File to read/write (can also be a directory)
-#' @param overwrite Pass \code{TRUE} to overwrite if the file/directory already
+#' @param overwrite Pass `TRUE` to overwrite if the file/directory already
 #'   exists.
 #' @param validate Flag to validate mudata object after read or before write
 #' @param update_columns Update the columns table "type" column to reflect the
@@ -386,11 +386,10 @@ type_strs_from_columns <- function(columns_tbl) {
   
   # create list of type_str named lists
   type_str_tbl <- type_str_tbl %>%
-    tidyr::nest(c("column", "type"), .key = "types")
-  type_strs <- type_str_tbl$types %>%
-    lapply(tibble::deframe) %>%
-    stats::setNames(type_str_tbl$table)
-  type_strs
+    dplyr::group_by_at("table") %>% 
+    tidyr::nest()
+  type_str_tbl$data <- lapply(type_str_tbl$data, tibble::deframe)
+  tibble::deframe(type_str_tbl)
 }
 
 #' Update the columns table
@@ -445,10 +444,10 @@ update_columns_table <- function(md, quiet = FALSE) {
 
 #' Prepare mudata table columns for writing
 #' 
-#' This set of generics is similar to \link[readr]{output_column} in that it
+#' This set of generics is similar to [output_column][readr::output_column] in that it
 #' converts columns to a form suitable to writing.
-#' \code{mudata_prepare_column} in combination with is 
-#' intended to be opposites with \code{mudata_parse_column} except for 
+#' `mudata_prepare_column` in combination with is 
+#' intended to be opposites with `mudata_parse_column` except for 
 #' date/time vectors that are not in UTC (mudata_parse_column assumes UTC,
 #' and mudata_prepare_column always converts to UTC with a message).
 #' 
@@ -461,7 +460,7 @@ update_columns_table <- function(md, quiet = FALSE) {
 #'
 #' @param x A an object
 #' @param format csv, json, or NA for unknown, 
-#' @param type_str A type string, generated by the internal \code{generate_type_str}
+#' @param type_str A type string, generated by the internal `generate_type_str`
 #' @param ... Passed to methods
 #'
 #' @return An atomic vector
